@@ -365,7 +365,6 @@ CLASS_OVERRIDES = {
 
 
 def autoflake(text: str, **kwargs: Any) -> str:
-
     kwargs.setdefault("remove_all_unused_imports", True)
     kwargs.setdefault("remove_unused_variables", True)
     return fix_code(text, **kwargs)
@@ -782,7 +781,7 @@ class Member:
 
     @property
     def type_string(self) -> str:
-        """single type, without Optional, etc..."""
+        """Single type, without Optional, etc..."""
         if self.key in OVERRIDES:
             return OVERRIDES[self.key].type_
         if isinstance(self.component, (XsdAnyElement, XsdAnyAttribute)):
@@ -813,7 +812,7 @@ class Member:
 
     @property
     def full_type_string(self) -> str:
-        """full type, like Optional[List[str]]."""
+        """Full type, like Optional[List[str]]."""
         if self.key in OVERRIDES and self.type_string:
             return f": {self.type_string}"
         type_string = self.type_string
@@ -919,7 +918,7 @@ class MemberSet:
         return any(m.is_nonref_id for m in self._members)
 
     @property
-    def non_defaults(self) -> "MemberSet":
+    def non_defaults(self) -> MemberSet:
         return MemberSet(m for m in self._members if not m.default_val_str)
 
     def __iter__(self) -> Iterator[Member]:
