@@ -1271,47 +1271,47 @@ _lists = {
     "Map": {"M"},
     "Shape": {"AnnotationRef"},
     "OME": {
-        "Experimenter",
         "Dataset",
         "Instrument",
-        "Screen",
-        "ExperimenterGroup",
-        "Image",
-        "Project",
+        "Experimenter",
         "Experiment",
-        "ROI",
         "Folder",
+        "ExperimenterGroup",
+        "Project",
+        "ROI",
+        "Image",
+        "Screen",
         "Plate",
     },
-    "Image": {"MicrobeamManipulationRef", "AnnotationRef", "ROIRef"},
-    "Pixels": {"Plane", "TiffData", "Channel", "BinData"},
+    "Image": {"MicrobeamManipulationRef", "ROIRef", "AnnotationRef"},
+    "Pixels": {"TiffData", "Channel", "BinData", "Plane"},
     "Plane": {"AnnotationRef"},
     "Channel": {"AnnotationRef"},
-    "MicrobeamManipulation": {"Type", "ROIRef", "LightSourceSettings"},
+    "MicrobeamManipulation": {"LightSourceSettings", "ROIRef", "Type"},
     "Instrument": {
-        "Filter",
-        "FilterSet",
-        "Detector",
+        "Dichroic",
         "AnnotationRef",
         "Objective",
-        "Dichroic",
+        "Detector",
+        "Filter",
+        "FilterSet",
     },
-    "Project": {"DatasetRef", "AnnotationRef"},
-    "ExperimenterGroup": {"Leader", "AnnotationRef", "ExperimenterRef"},
+    "Project": {"AnnotationRef", "DatasetRef"},
+    "ExperimenterGroup": {"Leader", "ExperimenterRef", "AnnotationRef"},
     "Dataset": {"ImageRef", "AnnotationRef"},
-    "Experiment": {"Type", "MicrobeamManipulation"},
+    "Experiment": {"MicrobeamManipulation", "Type"},
     "Experimenter": {"AnnotationRef"},
-    "Folder": {"FolderRef", "AnnotationRef", "ImageRef", "ROIRef"},
+    "Folder": {"ImageRef", "ROIRef", "AnnotationRef", "FolderRef"},
     "Objective": {"AnnotationRef"},
     "Detector": {"AnnotationRef"},
     "FilterSet": {"ExcitationFilterRef", "EmissionFilterRef"},
     "Filter": {"AnnotationRef"},
     "Dichroic": {"AnnotationRef"},
-    "LightPath": {"ExcitationFilterRef", "AnnotationRef", "EmissionFilterRef"},
+    "LightPath": {"ExcitationFilterRef", "EmissionFilterRef", "AnnotationRef"},
     "ROI": {"AnnotationRef"},
-    "Plate": {"PlateAcquisition", "AnnotationRef", "Well"},
+    "Plate": {"AnnotationRef", "PlateAcquisition", "Well"},
     "Reagent": {"AnnotationRef"},
-    "Screen": {"Reagent", "AnnotationRef", "PlateRef"},
-    "PlateAcquisition": {"WellSampleRef", "AnnotationRef"},
-    "Well": {"AnnotationRef", "WellSample"},
+    "Screen": {"AnnotationRef", "PlateRef", "Reagent"},
+    "PlateAcquisition": {"AnnotationRef", "WellSampleRef"},
+    "Well": {"WellSample", "AnnotationRef"},
 }
